import { Server } from "socket.io";
import {TSocket} from "../utilities/Types";
import ZoneRepository from "../repositories/ZoneRepository";
import ZoneManager from "../ZoneManager";
import {Character, Zone} from "@prisma/client";

interface IZoneLoad {
    zoneId: number;
}

/**
 * Handle character zone request event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:zone_editor:zone:request', async (data: IZoneLoad) => {
        console.log(`---GM ${socket.character?.id} has requested zone in zone editor.`);

        if (!data.zoneId) {
            console.log(`---Zone id not provided.`);
            return;
        }

        const zone = await ZoneRepository.getById(data.zoneId);

        if (!zone) {
            console.log(`---Zone not found.`);
            return;
        }

        socket.join(zone.id.toString());

        // send over zone and characters to socket
        socket.emit('gm:zone_editor:zone:load', {
            zone: zone
        });
    });
}